@@ -3,37 +3,38 @@ use warnings;
 use strict;
 use UNIVERSAL::require;
 
-our $VERSION = '0.1';
+our $VERSION = '0.12';
 
 sub request {
     my $self = shift;
-	my $what = shift;
+    my $what = shift;
     return $self->message($what . ' Request');
 }
 
 sub response {
     my $self = shift;
-	my $what = shift;
+    my $what = shift;
     return $self->message($what . ' Response');
 }
 
 sub message {
     my $self = shift;
+    my $base_class = ref $self || $self;
     my $type = camel(shift);
-    my $class = 'Net::OAuth::' . $type;
-	$class->require;
+    my $class = $base_class . '::' . $type;
+    $class->require;
     return $class;
 }
 
 sub camel {
-	my @words;
-	foreach (@_) {
-		while (/([A-Za-z0-9]+)/g) {
-			(my $word = $1) =~ s/authentication/auth/i;
-			push @words, $word;
-		}
-	}
-	my $name = join('', map("\u$_", @words));
+    my @words;
+    foreach (@_) {
+        while (/([A-Za-z0-9]+)/g) {
+            (my $word = $1) =~ s/authentication/auth/i;
+            push @words, $word;
+        }
+    }
+    my $name = join('', map("\u$_", @words));
 }
 
 =head1 NAME
@@ -258,9 +259,9 @@ The following signature methods are supported:
 
 =item * PLAINTEXT
 
-=item * HMAC_SHA1
+=item * HMAC-SHA1
 
-=item * RSA_SHA1
+=item * RSA-SHA1
 
 =back
 
@@ -272,13 +273,13 @@ If an unknown signature method is specified, the signing/verification will throw
 
 This method is a trivial signature which adds no security.  Not recommended.
 
-=head3 HMAC_SHA1 SIGNATURES
+=head3 HMAC-SHA1 SIGNATURES
 
 This method is available if you have Digest::HMAC_SHA1 installed.  This is by far the most commonly used method.
 
-=head3 RSA_SHA1 SIGNATURES
+=head3 RSA-SHA1 SIGNATURES
 
-To use RSA_SHA1 signatures, pass in a Crypt::OpenSSL::RSA object (or any object that can do $o->sign($str) and/or $o->verify($str, $sig))
+To use RSA-SHA1 signatures, pass in a Crypt::OpenSSL::RSA object (or any object that can do $o->sign($str) and/or $o->verify($str, $sig))
 
 E.g.
 
