@@ -7,11 +7,11 @@ sub allow_extra_params {1}
 
 =head1 NAME
 
-Net::OAuth::RequestTokenRequest - An OAuth protocol request for a Protected Resource
+Net::OAuth::ProtectedResourceRequest - An OAuth protocol request for a Protected Resource
 
 =head1 SEE ALSO
 
-L<Net::OAuth::Request>, L<http://oauth.net>
+L<Net::OAuth>, L<http://oauth.net>
 
 =head1 AUTHOR
 
